==> org.eclipse.mylyn.tasks.bugs.source_3.1.1.v20090411-0400-e3x.jar: org/eclipse/mylyn/internal/tasks/bugs/IRepositoryConstants.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2008 Tasktop Technologies and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Tasktop Technologies - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.tasks.bugs;

/**
 * @author Steffen Pingel
 */
public class IRepositoryConstants {

	@Deprecated
	public static final String BRANDING = "branding"; //$NON-NLS-1$

	public static final String COMPONENT = "component"; //$NON-NLS-1$

	public static final String CONNECTOR_KIND = "repositoryKind"; //$NON-NLS-1$

	public static final String DESCRIPTION = "description"; //$NON-NLS-1$

	public static final String PRODUCT = "product"; //$NON-NLS-1$

	public static final String PRODUCT_CATEGORY = "productCategory"; //$NON-NLS-1$

	public static final String PRODUCT_DESCRIPTION = "productDescription"; //$NON-NLS-1$

	public static final String PRODUCT_NAME = "productName"; //$NON-NLS-1$

	public static final String PRODUCT_TITLE = "productTitle"; //$NON-NLS-1$

	public static final String REPOSITORY_KIND = "repositoryKind"; //$NON-NLS-1$

	public static final String REPOSITORY_URL = "repositoryUrl"; //$NON-NLS-1$

}

==> org.eclipse.mylyn.tasks.bugs.source_3.2.0.v20090617-0100-e3x.jar: org/eclipse/mylyn/internal/tasks/bugs/IRepositoryConstants.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2008 Tasktop Technologies and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Tasktop Technologies - initial API and implementation
 *******************************************************************************/

package org.eclipse.mylyn.internal.tasks.bugs;

/**
 * @author Steffen Pingel
 */
public class IRepositoryConstants {

	@Deprecated
	public static final String BRANDING = "branding"; //$NON-NLS-1$

	public static final String COMPONENT = "component"; //$NON-NLS-1$

	public static final String CONNECTOR_KIND = "repositoryKind"; //$NON-NLS-1$

	public static final String DESCRIPTION = "description"; //$NON-NLS-1$

	public static final String PRODUCT = "product"; //$NON-NLS-1$

	@Deprecated
	public static final String PRODUCT_CATEGORY = "productCategory"; //$NON-NLS-1$

	@Deprecated
	public static final String PRODUCT_DESCRIPTION = "productDescription"; //$NON-NLS-1$

	@Deprecated
	public static final String PRODUCT_NAME = "productName"; //$NON-NLS-1$

	@Deprecated
	public static final String PRODUCT_TITLE = "productTitle"; //$NON-NLS-1$

	@Deprecated
	public static final String REPOSITORY_KIND = "repositoryKind"; //$NON-NLS-1$

	public static final String REPOSITORY_URL = "repositoryUrl"; //$NON-NLS-1$

	public static final String SEVERITY = "severity"; //$NON-NLS-1$

	public static final String VERSION = "version"; //$NON-NLS-1$

	public static final String SUMMARY = "summary"; //$NON-NLS-1$

	public static final String PRIORITY = "priority"; //$NON-NLS-1$

	public static final String MAPPING_COMPLETE = "org.eclipse.mylyn.tasks.bugs.mappingComplete"; //$NON-NLS-1$

}
